@@ -2,7 +2,7 @@
   equate.cc
 
   Copyright (c) 1999 Paul Schulz
-  Copyright (c) 1999-2000 Dragos Acostachioaie
+  Copyright (c) 1999-2001 Dragos Acostachioaie
 
   This file is part of DOC++.
 
@@ -53,7 +53,7 @@ void help()
     printf(_("  -d  --dir DIR          use DIR for the output directory\n"));
     printf(_("  -f  --file FILE        read FILE instead of gif.db as GIF database\n"));
     printf(_("                         (relative to . or DIR)\n\n"));
-    printf(_("Mail bug reports and suggestions to <docpp@egroups.com>\n"));
+    printf(_("Mail bug reports and suggestions to <docpp@yahoogroups.com>\n"));
 }
 
 void missingArg(char *s)
